@@ -19,7 +19,8 @@ sub new {
 
 sub build_requires {
     return +{
-	'Test::More'	=> 0.88,	# Because of done_testing().
+	'Test::More'	=> 0.40,
+##	'Test::More'	=> 0.88,	# Because of done_testing().
     };
 }
 
@@ -28,44 +29,8 @@ sub distribution {
     return $self->{distribution};
 }
 
-sub meta_merge {
-    my ( undef, @extra ) = @_;
-    return {
-	'meta-spec'	=> {
-	    version	=> 2,
-	},
-	no_index	=> {
-	    directory	=> [ qw{ inc t xt } ],
-	},
-	resources	=> {
-	    bugtracker	=> {
-                web	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-UTDF',
-#                mailto  => 'wyant@cpan.org',
-            },
-	    license	=> 'http://dev.perl.org/licenses/',
-	    repository	=> {
-		type	=> 'git',
-		url	=> 'git://github.com/trwyant/perl-Astro-UTDF.git',
-		web	=> 'https://github.com/trwyant/perl-Astro-UTDF',
-	    },
-	},
-	@extra,
-    };
-}
-
-sub provides {
-    -d 'lib'
-	or return;
-    local $@ = undef;
-    my $provides = eval {
-	require Module::Metadata;
-	Module::Metadata->provides( version => 2, dir => 'lib' );
-    } or return;
-    return ( provides => $provides );
-}
-
 sub requires {
-    my ( undef, @extra ) = @_;		# Invocant unused
+    my ( $self, @extra ) = @_;
 ##  if ( ! $self->distribution() ) {
 ##  }
     return +{
@@ -139,27 +104,6 @@ C<< {META_MERGE}->{build_requires} >> or C<BUILD_REQUIRES> key.
 This method returns the value of the environment variable
 C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
-=head2 meta_merge
-
- use YAML;
- print Dump( $meta->meta_merge() );
-
-This method returns a reference to a hash describing the meta-data which
-has to be provided by making use of the builder's C<meta_merge>
-functionality. This includes the C<no_index> and C<resources> data.
-
-Any arguments will be appended to the generated array.
-
-=head2 provides
-
- use YAML;
- print Dump( [ $meta->provides() ] );
-
-This method attempts to load L<Module::Metadata|Module::Metadata>. If
-this succeeds, it returns a C<provides> entry suitable for inclusion in
-L<meta_merge()|/meta_merge> data (i.e. C<'provides'> followed by a hash
-reference). If it can not load the required module, it returns nothing.
-
 =head2 requires
 
  use YAML;
@@ -204,7 +148,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2019 by Thomas R. Wyant, III
+Copyright (C) 2010-2011 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
